Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EmailAddressPartially ¶
EmailAddressPartially obfuscates the email address by masking everything but the first and last character of each part (except TLD). At least some characters of the local part will always be masked.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.